@@ -416,12 +416,13 @@ def bStrByTimestamp(timestamp=None, fmt=None):
 
 _defaultHeader = {
     'Connection': 'keep-alive',
-    'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36',
+    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36',
     'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
     'Accept-Encoding': 'gzip',
     'Accept-Language': 'zh-CN,zh;q=0.8',
 }
 
+
 # Cookie
 _cookie = http.cookiejar.CookieJar()
 _cookieProc = urllib.request.HTTPCookieProcessor(_cookie)
@@ -521,6 +522,13 @@ def bXToInt(value):
     return int(value, len(_xPar))
 
 
+async def bAsyncAwait(*taskList):
+    resultList = []
+    for task in taskList:
+        resultList.append(await task)
+    return resultList
+
+
 async def bAsyncWriteFile(file, data, encoding='utf8', newline='\n'):
     import aiofiles
     bMakeFolder(os.path.dirname(file))
@@ -612,9 +620,9 @@ async def bAsyncExecute(*parList):
     return proc.returncode, stdout, stderr
 
 
-_maxAsyncHttpNum = 1000
+_maxAsyncHttpNum = 3
 _currentAsyncHttpNum = 0
-_waitAsyncHttpTime = 0.5
+_waitAsyncHttpTime = 0.1
 
 
 def bSetAsyncHttpMaxNum(value):
@@ -691,6 +699,11 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
     return result, response
 
 
+async def bAsyncDownload(url, file):
+    result, _response = await bAsyncHttpGet(self.url)
+    await bAsyncWriteBinFile(file, result)
+
+
 isImportAioHttp = True
 
 
